==> flask-ligand-0.1.2.tar.gz: flask-ligand-0.1.2/CHANGELOG.md <==
Changelog
=========

<!--next-version-placeholder-->

## v0.1.2 (2022-08-18)
### :robot:
* [504:robot:] Fix Configuration Setting Issue and Update Docs ([`c3aea6c`](https://github.com/cowofevil/flask-ligand/commit/c3aea6c9f40b9f1bd2dd3da96f551733985c0332))

### Other
* [CHORE] Merge Coverage and Mypy Configuration into Pyproject ([`c187bf4`](https://github.com/cowofevil/flask-ligand/commit/c187bf42dea9b6316dee5a49eed2e9473e2f39c3))

## v0.1.1 (2022-08-18)
### :robot:
* [FIX:robot:] Update Flask and Fix Type Checking ([`7dbc587`](https://github.com/cowofevil/flask-ligand/commit/7dbc587d71bee3b111dc03ff539222959cbce426))

### Other
* :arrow_up: Update flask-smorest requirement from ~=0.38 to ~=0.39 ([`77d3679`](https://github.com/cowofevil/flask-ligand/commit/77d3679b1671a8ad3d405ded3a9c86e8c6713b32))
* :arrow_up: Update pygments requirement from ~=2.12 to ~=2.13 ([`1d75cd5`](https://github.com/cowofevil/flask-ligand/commit/1d75cd5e8b752a1f0c3dbffc67c07baa7f3c693b))
* :arrow_up: Update sqlalchemy-utils requirement from ~=0.32 to ~=0.38 ([`475ac06`](https://github.com/cowofevil/flask-ligand/commit/475ac0671becde3392d063c9045779bfed3c3fb8))

## v0.1.0 (2022-08-17)
### :sparkles:
* [473:sparkles:] Sanitize Codebase and Rename Everything to 'flask-ligand' ([`730dc0c`](https://github.com/cowofevil/flask-ligand/commit/730dc0c2825a8f0c40fee141e2001c46ec924700))

### Other
* Initial commit ([`7893f0d`](https://github.com/cowofevil/flask-ligand/commit/7893f0de70b26a853ad86a243d16b2d5589ba968))

==> flask-ligand-0.2.0.tar.gz: flask-ligand-0.2.0/CHANGELOG.md <==
Changelog
=========

<!--next-version-placeholder-->

## v0.2.0 (2022-08-27)
### :sparkles:
* [510:sparkles:] Configurable Roles for RBAC Verification ([`d8e80a4`](https://github.com/cowofevil/flask-ligand/commit/d8e80a428875958a9af7e6774c8cfa2a370dab94))

### Other
* :arrow_up: Update types-setuptools requirement from ~=63.4 to ~=65.1 ([`7c8ef3a`](https://github.com/cowofevil/flask-ligand/commit/7c8ef3a6f19bf1f752d25f92ced9f22c67a24986))

## v0.1.3 (2022-08-25)
### :robot:
* [507:robot:] Configure Database Provider and URI ([`7e3d0c7`](https://github.com/cowofevil/flask-ligand/commit/7e3d0c7e1ce231893be80b6fd78802f0f589c347))

### Other
* [FIX] Enable SQLite Memory Database URI for Local Environment ([`fd5de8a`](https://github.com/cowofevil/flask-ligand/commit/fd5de8a4e7ad60368caa4e5c4604a944ab54c3dd))

## v0.1.2 (2022-08-18)
### :robot:
* [504:robot:] Fix Configuration Setting Issue and Update Docs ([`c3aea6c`](https://github.com/cowofevil/flask-ligand/commit/c3aea6c9f40b9f1bd2dd3da96f551733985c0332))

### Other
* [CHORE] Merge Coverage and Mypy Configuration into Pyproject ([`c187bf4`](https://github.com/cowofevil/flask-ligand/commit/c187bf42dea9b6316dee5a49eed2e9473e2f39c3))

## v0.1.1 (2022-08-18)
### :robot:
* [FIX:robot:] Update Flask and Fix Type Checking ([`7dbc587`](https://github.com/cowofevil/flask-ligand/commit/7dbc587d71bee3b111dc03ff539222959cbce426))

### Other
* :arrow_up: Update flask-smorest requirement from ~=0.38 to ~=0.39 ([`77d3679`](https://github.com/cowofevil/flask-ligand/commit/77d3679b1671a8ad3d405ded3a9c86e8c6713b32))
* :arrow_up: Update pygments requirement from ~=2.12 to ~=2.13 ([`1d75cd5`](https://github.com/cowofevil/flask-ligand/commit/1d75cd5e8b752a1f0c3dbffc67c07baa7f3c693b))
* :arrow_up: Update sqlalchemy-utils requirement from ~=0.32 to ~=0.38 ([`475ac06`](https://github.com/cowofevil/flask-ligand/commit/475ac0671becde3392d063c9045779bfed3c3fb8))

## v0.1.0 (2022-08-17)
### :sparkles:
* [473:sparkles:] Sanitize Codebase and Rename Everything to 'flask-ligand' ([`730dc0c`](https://github.com/cowofevil/flask-ligand/commit/730dc0c2825a8f0c40fee141e2001c46ec924700))

### Other
* Initial commit ([`7893f0d`](https://github.com/cowofevil/flask-ligand/commit/7893f0de70b26a853ad86a243d16b2d5589ba968))
